<template>
    <div class="app-container">
       <el-form :model="queryParams" ref="queryRef" :inline="true">
          <el-form-item prop="name">
             <el-input
                v-model="queryParams.name"
                placeholder="请输入内容"
                clearable
                style="width: 200px"
                @keyup.enter="handleQuery"
             />
          </el-form-item>
          <el-form-item>
             <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
             <el-button icon="Refresh" @click="resetQuery">重置</el-button>
          </el-form-item>
       </el-form>
 
       <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
             <el-button
                type="primary"
                plain
                icon="Plus"
                @click="handleAdd"
             >新增</el-button>
          </el-col>
       </el-row>
       <!--表格及分页-->
       <el-table v-loading="loading" :data="tableData">
          <el-table-column
            v-for="(item, key, index) of tableHeader"
            :prop="key.toString()"
            :label="item"
            :key="index"
            align="center"
          >
        </el-table-column>
          <el-table-column label="操作" width="180" align="center" class-name="small-padding fixed-width">
             <template #default="scope">
                <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)">修改</el-button>
                <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)">删除</el-button>
             </template>
          </el-table-column>
        </el-table>
        <pagination
          :total="pageParam.total"
          v-model:page="pageParam.page"
          v-model:limit="pageParam.limit"
          :page-sizes="[10,20,30]"
          @pagination="getList"
        />
       <!-- 添加或修改对话框 -->
       <el-dialog :title="title" v-model="open" append-to-body center>
          <el-form class="form-box" ref="formRef" :model="form" :rules="rules" label-width='auto'>
                   <el-form-item label="水费账单类型"  prop="waterBillType">
                        <el-select v-model="form.waterBillType" placeholder="请选择水费账单类型">
                            <el-option 
                            v-for="(item,index) in waterBillTypeList"
                            :label="item.dictLabel"
                            :value="item.dictValue"
                            :key="index"
                            ></el-option>
                        </el-select>
                   </el-form-item>
                   <el-form-item label="账单周期" prop="waterMonthBillDay">
                     <div> 
                        <el-input-number v-model="form.waterMonthBillDay" :min="1" max="31" />
                        <span>(n日 ~ 次月n-1日)</span>
                     </div>
                   </el-form-item>
                   <el-form-item label="出账后支付时间限制" prop="waterPayDays">
                      <el-input v-model="form.waterPayDays" placeholder="请输入出账后支付时间限制(单位:天)" />
                   </el-form-item>
                    <el-form-item label="账单出账日" prop="waterMonthBillCreateDay">
                      <el-input-number v-model="form.waterMonthBillCreateDay" :min="1" max="31" placeholder="请输入水费账单生成日期" />
                   </el-form-item>
                   <el-form-item label="水表欠费是否关阀 " prop="waterMeterDelinquentClose">
                        <el-select v-model="form.waterMeterDelinquentClose" placeholder="请选择">
                            <el-option 
                            v-for="(item,index) in waterMeterDelinquentCloseList"
                            :label="item.dictLabel"
                            :value="item.dictValue"
                            :key="index"
                            ></el-option>
                        </el-select>
                   </el-form-item>
              <el-form-item></el-form-item>
          </el-form>
          <template #footer>
             <div class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
             </div>
          </template>
       </el-dialog>
    </div>
 </template>
 
 <script setup name="Menu">
 import  companySetting from "@/api/configuration/companySetting";
 import  { sysDictData } from "@/api/system/dict";
 import setPostParams from "@/utils/searchParams.js";
 const { proxy } = getCurrentInstance();
 
/**
 * 搜索相关
 */
 /** 搜索按钮操作 */
 function handleQuery() {
   getList({keywords:queryParams.value.name,page:1})
 }
 
 /** 重置按钮操作 */
 function resetQuery() {
   proxy.resetForm("queryRef");
   handleQuery();
 }

 /**
  *  Table表格权限数据列表相关
  */

const pageParam = ref({
    total:0,
    limit:0,
    page:0,
})
const tableData = ref([]);
let  tableHeader = ref({
        waterBillTypeName: '水费账单类型',
        waterMonthBillDay: '水费账单起始日期（日）',
        waterMonthBillCreateDay: '水费账单生成日期（天）',
        waterPayDays: '出账后支付时间限制（天）',
        waterMeterDelinquentCloseName: '水表欠费是否关阀',
   })
 /** 获取列表 */
 async function getList(val) {
      loading.value = true;

     let postParam = setPostParams(val)
      await companySetting().search(postParam).then((res) =>{
        tableData.value = res.data.list
          tableData.value.forEach((item)=>{
              if(item.waterBillType === 2){
                  item.waterBillTypeName = '每日'
              }else{
                  item.waterBillTypeName = '每月'
              }
              if(item.waterMeterDelinquentClose === 0){
                  item.waterMeterDelinquentCloseName = '否'
              }else{
                  item.waterMeterDelinquentCloseName = '是'
              }
          })
        pageParam.value.total = res.data.total
        pageParam.value.limit = res.data.limit
        pageParam.value.page = res.data.page
    })
    loading.value = false;
 }
 
 /** 新增按钮操作 */
 async function handleAdd() {
   reset();
   open.value = true;
   title.value = "新增用户分类";
 }
 
 /** 修改按钮操作 */
 async function handleUpdate(row) {
   reset();
   form.value = Object.assign({},row)
   form.value.waterBillType = form.value.waterBillType.toString()
   form.value.waterMeterDelinquentClose = form.value.waterMeterDelinquentClose.toString()
   open.value = true;
   title.value = "修改用户分类";
 }

/** 删除按钮操作 */
function handleDelete(row) {
  proxy.$modal.confirm('是否确认删除名称为"' + row.waterBillType + '"的数据项?').then(function() {
    return companySetting().remove(row.id);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

 /**
  *  新增/修改弹窗Form表单相关
  */
const open = ref(false);
const loading = ref(false);
const title = ref("");

const data = reactive({
form:{},
queryParams: {
    name: undefined,
},
rules: {
    waterBillType: [{ required: true, message: "请输入水费账单类型", trigger: "blur" }],
    waterMonthBillDay: [
      { required: true, message: "请输入水费账单起始日期", trigger: "blur" }],
      // { pattern: /^(3[01]|[12][0-9]|[1-9])$/,message: '日期必须在1到31之间',trigger: 'blur'} ],
    waterMonthBillCreateDay: [
      { required: true, message: "请输入出账后支付时间限制", trigger: "blur" }],
      // { pattern: /^(3[01]|[12][0-9]|[1-9])$/,message: '日期必须在1到31之间',trigger: 'blur'} ],
    waterPayDays: [{ required: true, message: "出账后支付时间限制", trigger: "blur" }],
    waterMeterDelinquentClose: [{ required: true, message: "请选择", trigger: "blur" }],
},
});
const { queryParams, form, rules } = toRefs(data);

//获取账单类型字典
const waterBillTypeList = ref()
const getBillType = async() =>{
   await sysDictData().searchType('billDate_type').then((res) =>{
   waterBillTypeList.value = res.data
    })
}
//获取欠费是否关阀字典
const waterMeterDelinquentCloseList = ref()
const getvalveType = async() =>{
   await sysDictData().searchType('isCloseValve_type').then((res) =>{
      waterMeterDelinquentCloseList.value = res.data
    })
}
//动态显示

 /** 提交按钮 */
 function submitForm() {
   proxy.$refs["formRef"].validate(valid => {
     if (valid) {
       if (form.value.id != undefined) {
         companySetting().modify(form.value).then(res => {
           proxy.$modal.msgSuccess("修改成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("修改失败");
         });
       } else {
         companySetting().create(form.value).then(res => {
           proxy.$modal.msgSuccess("新增成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("新增失败");
         });;
       }
     }
   });
 }

 /** 取消按钮 */
 function cancel() {
   open.value = false;
   reset();
 }
 
 /** 表单重置 */
 function reset() {
   form.value = {
        waterBillType: '',
        waterMonthBillCreateDay: '',
        waterMonthBillDay:undefined,
        waterPayDays:undefined,
        waterMeterDelinquentClose:undefined,
   };
   proxy.resetForm("formRef");
 }
 getvalveType()
 getBillType()
 getList();
 </script>
 